==> enterprisemodules-wls_install-3.7.3.tar.gz: enterprisemodules-wls_install-3.7.3/lib/puppet/type/wls_adminserver.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  Type.newtype(:wls_adminserver) do
    def self.module_name; 'wls_install'; end
    desc 'control the adminserver state like running,stop,restart'

    newproperty(:ensure) do
      desc 'Whether to do something.'

      newvalue(:start, :event => :adminserver_running) do
        unless resource[:refreshonly] == :true
          provider.start
        end
      end

      newvalue(:stop, :event => :adminserver_stop) do
        unless resource[:refreshonly] == :true
          provider.stop
        end
      end

      aliasvalue(:running, :start)
      aliasvalue(:abort, :stop)

      def retrieve
        provider.status
      end

      def insync?(is)
        if resource[:refreshonly] == :true
          true
        else
          super
        end
      end
    end

    newparam(:name) do
      desc <<-EOT
        The title.
      EOT
      isnamevar
    end

    newparam(:server_name) do
      desc <<-EOT
        The adminserver name.
      EOT
    end

    newparam(:ohs_standalone_server) do
      desc <<-EOT
        Flag to determinate if the server is a OHS standalone server.
      EOT

      newvalues(:true, :false)

      defaultto :false
    end

    newparam(:domain_name) do
      desc <<-EOT
        The weblogic domain name.
      EOT
    end

    newparam(:domain_path) do
      desc <<-EOT
        The full domain path.
      EOT
    end

    newparam(:os_user) do
      desc <<-EOT
        The weblogic operating system user.
      EOT
    end

    newparam(:weblogic_home_dir) do
      desc <<-EOT
        The weblogic home folder.
      EOT
    end

    newparam(:weblogic_user) do
      desc <<-EOT
        The weblogic user.
      EOT
    end

    newparam(:weblogic_password) do
      desc <<-EOT
        The weblogic user password.
      EOT
    end

    newparam(:jdk_home_dir) do
      desc <<-EOT
        The jdk home dir.
      EOT
    end

    newparam(:nodemanager_address) do
      desc <<-EOT
        The nodemanager address.
      EOT
    end

    newparam(:nodemanager_port) do
      desc <<-EOT
        The nodemanager port.
      EOT
    end

    newparam(:nodemanager_secure_listener) do
      desc <<-EOT
        The nodemanager secure listener true or false.
      EOT

      newvalues(:true, :false)

      defaultto :true
    end

    newparam(:jsse_enabled) do
      desc <<-EOT
        The jsse enabled.
      EOT
      newvalues(:true, :false)

      defaultto :false
    end

    newparam(:custom_trust) do
      desc <<-EOT
        The custom trust enabled.
      EOT
      newvalues(:true, :false)

      defaultto :false
    end

    newparam(:trust_keystore_file) do
      desc <<-EOT
        The trust keystore full path.
      EOT
    end

    newparam(:trust_keystore_passphrase) do
      desc <<-EOT
        The trust keystore password.
      EOT

    end

    newparam(:refreshonly) do
      desc <<-EOT
        The command should only be run as a
        refresh mechanism for when a dependent object is changed.
      EOT

      newvalues(:true, :false)

      defaultto :false
    end

    def refresh
      Puppet.info 'wls_adminserver refresh'
      provider.restart
    end

  end
end

==> enterprisemodules-wls_install-4.2.4.tar.gz: enterprisemodules-wls_install-4.2.4/lib/puppet/type/wls_adminserver.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  Type.newtype(:wls_adminserver) do
    def self.module_name
      'wls_install'
    end
    desc 'control the adminserver state like running,stop,restart'

    newproperty(:ensure) do
      desc 'Whether to do something.'

      newvalue(:start, :event => :adminserver_running) do
        provider.start unless resource[:refreshonly] == true
      end

      newvalue(:stop, :event => :adminserver_stop) do
        provider.stop unless resource[:refreshonly] == true
      end

      aliasvalue(:running, :start)
      aliasvalue(:abort, :stop)

      def retrieve
        provider.status
      end

      def insync?(its)
        if resource[:refreshonly] == true
          true
        else
          super
        end
      end
    end

    newparam(:name) do
      desc <<-DESC
        The title.
      DESC
      isnamevar
    end

    newparam(:server_name) do
      desc <<-DESC
        The adminserver name.
      DESC
    end

    newparam(:ohs_standalone_server) do
      desc <<-DESC
        Flag to determinate if the server is a OHS standalone server.
      DESC

      newvalues(true, false)

      defaultto false
    end

    newparam(:domain_name) do
      desc <<-DESC
        The weblogic domain name.
      DESC
    end

    newparam(:domain_path) do
      desc <<-DESC
        The full domain path.
      DESC
    end

    newparam(:os_user) do
      desc <<-DESC
        The weblogic operating system user.
      DESC
    end

    newparam(:weblogic_home_dir) do
      desc <<-DESC
        The weblogic home folder.
      DESC
    end

    newparam(:weblogic_user) do
      desc <<-DESC
        The weblogic user.
      DESC
    end

    newparam(:weblogic_password) do
      desc <<-DESC
        The weblogic user password.
      DESC
    end

    newparam(:jdk_home_dir) do
      desc <<-DESC
        The jdk home dir.
      DESC
    end

    newparam(:nodemanager_address) do
      desc <<-DESC
        The nodemanager address.
      DESC
    end

    newparam(:nodemanager_port) do
      desc <<-DESC
        The nodemanager port.
      DESC
    end

    newparam(:nodemanager_secure_listener) do
      desc <<-DESC
        The nodemanager secure listener true or false.
      DESC

      newvalues(true, false)

      defaultto true
    end

    newparam(:jsse_enabled) do
      desc <<-DESC
        The jsse enabled.
      DESC
      newvalues(true, false)

      defaultto false
    end

    newparam(:custom_trust) do
      desc <<-DESC
        The custom trust enabled.
      DESC
      newvalues(true, false)

      defaultto false
    end

    newparam(:trust_keystore_file) do
      desc <<-DESC
        The trust keystore full path.
      DESC
    end

    newparam(:trust_keystore_passphrase) do
      desc <<-DESC
        The trust keystore password.
      DESC
    end

    newparam(:refreshonly) do
      desc <<-DESC
        The command should only be run as a
        refresh mechanism for when a dependent object is changed.
      DESC

      newvalues(true, false)

      defaultto false
    end

    def refresh
      Puppet.info 'wls_adminserver refresh'
      provider.restart
    end
  end
end
